get_query_content: Parse out json response from httr object

View source: R/query.R

get_query_contentR Documentation

Parse out json response from httr object

Description

Parse out json response from httr object

Usage

get_query_content(response)

Arguments

response

Output from api_query()

Value

Parsed json output from query, often in form of data frame. If status code is not successful then return the actual response


ieugwasr documentation built on Oct. 7, 2026, 5:08 p.m.